"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringIdAnswersToModel = exports.stringIdPrompts = exports.getEntityFromAnswers = void 0;
const cuba_model_utils_1 = require("../../../../common/model/cuba-model-utils");
const entity_1 = require("../entity");
const questions_1 = require("../../../../common/questions");
const questions_2 = require("../questions");
function getEntityFromAnswers(answers, cubaProjectModel) {
    const entityName = answers.entity.name;
    if (!entityName) {
        throw Error('Additional prompt failed: cannot find entity name');
    }
    const entity = cuba_model_utils_1.findEntity(cubaProjectModel, entityName);
    if (!entity) {
        throw Error('Additional prompt failed: cannot find entity');
    }
    return entity;
}
exports.getEntityFromAnswers = getEntityFromAnswers;
async function stringIdPrompts(gen, entity, cubaProjectModel, listShowIdQuestions, listIdPositionQuestion, editIdPositionQuestion) {
    let stringIdAnswers = {};
    if (entity_1.isStringIdEntity(cubaProjectModel, entity)) {
        let idAttrNameAnswers = {};
        if (entity.idAttributeName == null) {
            // Seems that the project model was created with an older version of Studio.
            // Ask for ID attribute name.
            idAttrNameAnswers = await gen.prompt(questions_1.fromStudioProperties(questions_2.idAttrNameQuestions, cubaProjectModel));
        }
        // Ask whether to show the ID field in the List component
        const showIdAnswers = await gen.prompt(questions_1.fromStudioProperties(listShowIdQuestions, cubaProjectModel));
        // Ask at which position to show the ID field in the List and Edit components
        const idPositionQuestions = [];
        if (showIdAnswers.listShowIdAttr) {
            idPositionQuestions.push(listIdPositionQuestion);
        }
        if (editIdPositionQuestion != null) {
            idPositionQuestions.push(editIdPositionQuestion);
        }
        let idPositionAnswers = {};
        if (idPositionQuestions.length > 0) {
            idPositionAnswers = await gen.prompt(questions_1.fromStudioProperties(idPositionQuestions, cubaProjectModel));
        }
        stringIdAnswers = { ...idAttrNameAnswers, ...showIdAnswers, ...idPositionAnswers };
    }
    return stringIdAnswers;
}
exports.stringIdPrompts = stringIdPrompts;
function stringIdAnswersToModel(answers, projectModel, entity, listAttributesArg, editAttributesArg) {
    const listAttributes = listAttributesArg.slice();
    const editAttributes = editAttributesArg?.slice();
    if (!entity_1.isStringIdEntity(projectModel, entity)) {
        return {
            listAttributes,
            editAttributes: editAttributes
        };
    }
    const stringIdName = answers.entity.idAttributeName ?? answers.idAttrName;
    if (stringIdName == null) {
        throw new Error('Could not find the stringIdName');
    }
    const allEntityAttributes = cuba_model_utils_1.collectAttributesFromHierarchy(entity, projectModel);
    const idAttr = allEntityAttributes.find(attr => attr.name === stringIdName);
    if (idAttr == null) {
        throw new Error(`Unable to find ID attribute. Expected the ID attribute to be named "${stringIdName}".`);
    }
    if (editAttributes != null && stringIdName !== 'id') {
        const impostorAttrIndex = editAttributes.findIndex(attr => attr.name === 'id');
        if (impostorAttrIndex !== -1) {
            // An edge case when we have a non-ID string attribute named "id", and a differently named ID attribute.
            // We do not show the attribute named "id" in the editor.
            // We still show it in the List Component (it will display the same value as the real ID attribute).
            editAttributes.splice(impostorAttrIndex, 1);
        }
    }
    if (editAttributes != null && answers.editIdAttrPos != null) {
        editAttributes.splice(answers.editIdAttrPos, 0, idAttr);
    }
    if (answers.listShowIdAttr && answers.listIdAttrPos != null) {
        listAttributes.splice(answers.listIdAttrPos, 0, idAttr);
    }
    return {
        stringIdName,
        listAttributes,
        editAttributes: editAttributes
    };
}
exports.stringIdAnswersToModel = stringIdAnswersToModel;
//# sourceMappingURL=index.js.map